@@ -4,6 +4,7 @@ import os
 import sys
 import django
 import json
+import shutil
 import subprocess
 import webbrowser
 
@@ -14,9 +15,15 @@ CURRENT_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 BACKEND_DIR = os.path.join(CURRENT_DIR, "mercury")
 sys.path.insert(0, BACKEND_DIR)
 
-from demo import create_demo_notebook
+from demo import (
+    create_demo_notebook,
+    check_needed_packages,
+    create_simple_demo_notebook,
+    create_slides_demo_notebook,
+    create_welcome,
+)
 
-__version__ = "1.99.4"
+__version__ = "1.99.5"
 
 from widgets.manager import WidgetsManager
 from widgets.app import App
@@ -31,6 +38,8 @@ from widgets.multiselect import MultiSelect
 from widgets.outputdir import OutputDir
 from widgets.note import Note
 from widgets.button import Button
+from widgets.md import Markdown
+from widgets.md import Markdown as Md
 
 
 def main():
@@ -52,7 +61,6 @@ def main():
     os.environ["MERCURY_VERBOSE"] = str(VERBOSE)
     os.environ["DJANGO_LOG_LEVEL"] = "ERROR" if VERBOSE == 0 else "INFO"
 
-
     run_add_notebook = None
     if "run" in sys.argv:
         if os.environ.get("ALLOWED_HOSTS") is None:
@@ -79,10 +87,28 @@ def main():
         """
         print(logo)
 
+        if "clear" in sys.argv:
+            for n in ["db.sqlite", "db.sqlite3"]:
+                db_path = os.path.join(
+                    os.path.dirname(os.path.abspath(__file__)),
+                    n
+                )
+                if os.path.exists(db_path):
+                    os.remove(db_path) 
+                    print("SQLite database deleted")
+            print("All clear")
+            sys.exit(1)
+
         if "demo" in sys.argv:
-            create_demo_notebook("demo.ipynb")
+            check_needed_packages()
+            create_welcome("welcome.md")
+            create_simple_demo_notebook("demo.ipynb")
+            create_demo_notebook("demo-dataframe-and-plots.ipynb")
+            create_slides_demo_notebook("demo-slides.ipynb")
+
             sys.argv.remove("demo")
-            run_add_notebook = "demo.ipynb"
+            os.environ["NOTEBOOKS"] = "*.ipynb"
+            # run_add_notebook = "demo.ipynb"
         else:
             for l in sys.argv:
                 if l.endswith(".ipynb"):
@@ -151,9 +177,7 @@ def main():
                     worker_command, stdout=subprocess.PIPE, stderr=subprocess.PIPE
                 )
             else:
-                worker = subprocess.Popen(
-                    worker_command
-                )
+                worker = subprocess.Popen(worker_command)
 
             # celery worker beat for periodic tasks
             beat_command = [
@@ -169,7 +193,6 @@ def main():
                 beat_command, stdout=subprocess.PIPE, stderr=subprocess.PIPE
             )
 
-
             if "--runworker" in sys.argv:
                 sys.argv.remove("--runworker")
 
